from django.conf import settings

def debug():
    return {'debug': settings.DEBUG}

def site():
    from django.contrib.sites.models import Site
    return {'site': Site.objects.get_current()}

def django_settings():
    return {'settings': settings}

def i18n():
    from django.utils import translation

    return {
        'LANGUAGES': settings.LANGUAGES,
        'LANGUAGE_CODE': translation.get_language(),
        'LANGUAGE_BIDI': translation.get_language_bidi(),
    }



from django.conf import settings

def setting(name, default):
    @property
    def fn(self):
        return getattr(settings, 'EMAIL_%s' % name, default)
    return fn

class AppSettings(object):
    # Coffin users should use `coffin.template.loader.render_to_string`.
    RENDER_METHOD = setting('RENDER_METHOD', 'django.template.loader.render_to_string')

    CONTEXT_PROCESSORS = setting('CONTEXT_PROCESSORS', (
        'email_from_template.context_processors.debug',
        'email_from_template.context_processors.django_settings',
    ))

app_settings = AppSettings()



#!/usr/bin/env python3

from setuptools import setup, find_packages

setup(
    name='django-email-from-template',
    description="Send emails generated entirely from Django templates.",
    version='2.3.2',
    url='https://chris-lamb.co.uk/projects/django-email-from-template',

    author="Chris Lamb",
    author_email='chris@chris-lamb.co.uk',
    license="BSD",

    packages=find_packages(),
    package_data={'': [
        'templates/*/*',
    ]},

    install_requires=(
        'Django>=1.8',
    ),
)
